Bio2BEL MSIG
============
.. automodule:: bio2bel_msig

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cli
   manager
   models
   constants
   web

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
